import * as i0 from '@angular/core';
import { forwardRef, Directive, EventEmitter, Input, Output, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { not } from 'logical-not';
import { SubscribableDirective } from 'ngx-subscribable';
import { fromEvent } from 'rxjs';
import { filter } from 'rxjs/operators';

class FormControlCheckable {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(checked) {
        this.hostRef.nativeElement.checked = Boolean(checked);
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            if (host.checked)
                callback(host.value || true);
            else
                callback(null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlCheckable.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlCheckable, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlCheckable.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlCheckable, selector: "\n        sl-checkbox[formControlName],\n        sl-checkbox[formControl],\n        sl-switch[formControlName],\n        sl-switch[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlCheckable),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlCheckable, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-checkbox[formControlName],
        sl-checkbox[formControl],
        sl-switch[formControlName],
        sl-switch[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlCheckable),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlColorPicker {
    constructor(hostRef) {
        this.hostRef = hostRef;
        this.inited = false;
        this.initialValue = null;
        setTimeout(() => {
            this.inited = true;
            if (this.initialValue !== null)
                this.writeValue(this.initialValue);
        });
    }
    writeValue(value) {
        if (not(this.inited)) {
            this.initialValue = value;
            return;
        }
        this.hostRef.nativeElement.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(_) { }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlColorPicker.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlColorPicker, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlColorPicker.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlColorPicker, selector: "\n        sl-color-picker[formControlName],\n        sl-color-picker[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlColorPicker),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlColorPicker, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-color-picker[formControlName],
        sl-color-picker[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlColorPicker),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlNumber {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        if (not(Number.isNaN(value)) && Number.isFinite(value)) {
            this.hostRef.nativeElement.value = String(value);
        }
        else {
            this.hostRef.nativeElement.value = "";
        }
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        const event = host.tagName === "SL-INPUT" ? "sl-input" : "sl-change";
        host.addEventListener(event, () => {
            callback(host.value === "" ? null : parseFloat(host.value));
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlNumber.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlNumber, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlNumber.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlNumber, selector: "\n        sl-input[type=number][formControlName],\n        sl-input[type=number][formControl],\n        sl-range[formControlName],\n        sl-range[formControl],\n        sl-rating[formControlName],\n        sl-rating[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlNumber),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlNumber, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input[type=number][formControlName],
        sl-input[type=number][formControl],
        sl-range[formControlName],
        sl-range[formControl],
        sl-rating[formControlName],
        sl-rating[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlNumber),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlInput {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        this.hostRef.nativeElement.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-input", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlInput.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlInput, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlInput.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlInput, selector: "\n        sl-input:not([type=number])[formControlName],\n        sl-input:not([type=number])[formControl],\n        sl-textarea[formControlName],\n        sl-textarea[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlInput),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlInput, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input:not([type=number])[formControlName],
        sl-input:not([type=number])[formControl],
        sl-textarea[formControlName],
        sl-textarea[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlInput),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlRadio {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        const host = this.hostRef.nativeElement;
        host.checked = host.value === value;
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlRadio.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlRadio, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlRadio.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlRadio, selector: "\n        sl-radio[formControlName],\n        sl-radio[formControl],\n        sl-radio-button[formControlName],\n        sl-radio-button[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlRadio),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlRadio, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-radio[formControlName],
        sl-radio[formControl],
        sl-radio-button[formControlName],
        sl-radio-button[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlRadio),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class FormControlSelect {
    constructor(hostRef) {
        this.hostRef = hostRef;
    }
    writeValue(value) {
        const host = this.hostRef.nativeElement;
        if (host.multiple)
            host.value = Array.isArray(value) ? value : "";
        else
            host.value = String(value || "");
    }
    registerOnChange(callback) {
        const host = this.hostRef.nativeElement;
        host.addEventListener("sl-change", () => {
            callback(host.value || null);
        });
    }
    registerOnTouched(callback) {
        this.hostRef.nativeElement.addEventListener("sl-blur", callback);
    }
    setDisabledState(disabled) {
        this.hostRef.nativeElement.disabled = disabled;
    }
}
FormControlSelect.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlSelect, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
FormControlSelect.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: FormControlSelect, selector: "\n        sl-select[formControlName],\n        sl-select[formControl],\n    ", providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => FormControlSelect),
            multi: true,
        },
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: FormControlSelect, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-select[formControlName],
        sl-select[formControl],
    `,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => FormControlSelect),
                            multi: true,
                        },
                    ],
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

class AutofocusDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
    }
    ngAfterViewInit() {
        const host = this.hostRef.nativeElement;
        setTimeout(() => host.focus());
    }
}
AutofocusDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: AutofocusDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
AutofocusDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: AutofocusDirective, selector: "\n        sl-input[autofocus],\n        sl-textarea[autofocus],\n    ", usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: AutofocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-input[autofocus],
        sl-textarea[autofocus],
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; } });

function observe(element, eventName) {
    return fromEvent(element, eventName).pipe(filter((event) => (event === null || event === void 0 ? void 0 : event.target) === element));
}

class OpenDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.open = false;
        this.openChange = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-after-show").subscribe(() => this.changeOpen(true)),
            observe(host, "sl-after-hide").subscribe(() => this.changeOpen(false)),
        ];
    }
    ngOnChanges(changes) {
        if (changes.open)
            this.hostRef.nativeElement.open = changes.open.currentValue;
    }
    changeOpen(value) {
        this.open = value;
        this.openChange.emit(value);
    }
}
OpenDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: OpenDirective, selector: "\n        sl-alert[open],\n        sl-color-picker[open],\n        sl-details[open],\n        sl-dialog[open],\n        sl-drawer[open],\n        sl-dropdown[open],\n        sl-tooltip[open],\n    ", inputs: { open: "open" }, outputs: { openChange: "openChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-alert[open],
        sl-color-picker[open],
        sl-details[open],
        sl-dialog[open],
        sl-drawer[open],
        sl-dropdown[open],
        sl-tooltip[open],
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { open: [{
                type: Input
            }], openChange: [{
                type: Output
            }] } });

class OpenableDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.show = new EventEmitter();
        this.hide = new EventEmitter();
        this.afterShow = new EventEmitter();
        this.afterHide = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-show").subscribe(event => this.show.emit(event)),
            observe(host, "sl-hide").subscribe(event => this.hide.emit(event)),
            observe(host, "sl-after-show").subscribe(event => this.afterShow.emit(event)),
            observe(host, "sl-after-hide").subscribe(event => this.afterHide.emit(event)),
        ];
    }
}
OpenableDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenableDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenableDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: OpenableDirective, selector: "\n        sl-alert,\n        sl-details,\n        sl-dialog,\n        sl-drawer,\n        sl-dropdown,\n        sl-tooltip,\n    ", outputs: { show: "show", hide: "hide", afterShow: "afterShow", afterHide: "afterHide" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-alert,
        sl-details,
        sl-dialog,
        sl-drawer,
        sl-dropdown,
        sl-tooltip,
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { show: [{
                type: Output
            }], hide: [{
                type: Output
            }], afterShow: [{
                type: Output
            }], afterHide: [{
                type: Output
            }] } });
class OpenableExtendedDirective extends SubscribableDirective {
    constructor(hostRef) {
        super();
        this.hostRef = hostRef;
        this.initialFocus = new EventEmitter();
        this.requestClose = new EventEmitter();
    }
    ngOnInit() {
        const host = this.hostRef.nativeElement;
        this.subscriptions = [
            observe(host, "sl-initial-focus").subscribe(event => this.initialFocus.emit(event)),
            observe(host, "sl-request-close").subscribe(event => this.requestClose.emit(event)),
        ];
    }
}
OpenableExtendedDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenableExtendedDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
OpenableExtendedDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.0.2", type: OpenableExtendedDirective, selector: "\n        sl-dialog,\n        sl-drawer,\n    ", outputs: { initialFocus: "initialFocus", requestClose: "requestClose" }, usesInheritance: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: OpenableExtendedDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: `
        sl-dialog,
        sl-drawer,
    `,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { initialFocus: [{
                type: Output
            }], requestClose: [{
                type: Output
            }] } });

class ShoelaceStyleModule {
}
ShoelaceStyleModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: ShoelaceStyleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ShoelaceStyleModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.0.2", ngImport: i0, type: ShoelaceStyleModule, declarations: [AutofocusDirective,
        FormControlCheckable,
        FormControlColorPicker,
        FormControlInput,
        FormControlNumber,
        FormControlRadio,
        FormControlSelect,
        OpenableDirective,
        OpenableExtendedDirective,
        OpenDirective], exports: [AutofocusDirective,
        FormControlCheckable,
        FormControlColorPicker,
        FormControlInput,
        FormControlNumber,
        FormControlRadio,
        FormControlSelect,
        OpenableDirective,
        OpenableExtendedDirective,
        OpenDirective] });
ShoelaceStyleModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: ShoelaceStyleModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.2", ngImport: i0, type: ShoelaceStyleModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [
                        AutofocusDirective,
                        FormControlCheckable,
                        FormControlColorPicker,
                        FormControlInput,
                        FormControlNumber,
                        FormControlRadio,
                        FormControlSelect,
                        OpenableDirective,
                        OpenableExtendedDirective,
                        OpenDirective,
                    ],
                    declarations: [
                        AutofocusDirective,
                        FormControlCheckable,
                        FormControlColorPicker,
                        FormControlInput,
                        FormControlNumber,
                        FormControlRadio,
                        FormControlSelect,
                        OpenableDirective,
                        OpenableExtendedDirective,
                        OpenDirective,
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AutofocusDirective, FormControlCheckable, FormControlColorPicker, FormControlInput, FormControlNumber, FormControlRadio, FormControlSelect, OpenDirective, OpenableDirective, OpenableExtendedDirective, ShoelaceStyleModule };
//# sourceMappingURL=shoelace-style-angular.mjs.map
